#!/usr/bin/perl -w
# Chequeo pasivo generico
# Lee los servicios a chequear de /etc/nagios/check_nsca.conf
# Sustituye las variables $VAR$ por los valores pasados por linea de comandos
#
# 2014-05-05 daniel

use strict;
use Net::SNMP qw(:snmp);
use Data::Dumper;
use Getopt::Long;
use lib "/usr/lib64/nagios/plugins";
use utils qw($TIMEOUT %ERRORS &print_revision &support);
use ipsupervisor qw(&send_nsca &round &check_drbd &read_config $nagios_hostname $nagios_hostname_ha $nsca_host $debug $snmp_timeout);

my ($opt_h, $opt_V, $opt_v, $opt_N, $opt_H, $opt_U, $opt_d);
my $PROGNAME = $0;

sub print_usage();

&read_config();
$opt_H = $nagios_hostname if $nagios_hostname;
$opt_N = $nsca_host if $nsca_host;

Getopt::Long::Configure('bundling');
GetOptions
    ("h"   => \$opt_h, "help"           => \$opt_h,
     "V"   => \$opt_V, "version"        => \$opt_V,

     "N=s" => \$opt_N, "nsca=s"         => \$opt_N,
     "H=s" => \$opt_H, "hostname=s"     => \$opt_H,
     "U"   => \$opt_U, "unreachable"    => \$opt_U,
     "d"   => \$opt_d, "debug"          => \$opt_d);

if ($opt_V) {
    print_revision($PROGNAME,'1.0');
    exit $ERRORS{'OK'};
}

if ($opt_h) {
	print_usage();
	exit $ERRORS{'OK'};
}

# Hostname Centreon (requerido)
$opt_H = shift unless ($opt_H);
(print("Nagios hostname required!\n") && print_usage() && exit $ERRORS{'UNKNOWN'}) unless ($opt_H);

# NCSA Host (requerido)
$opt_N = shift unless ($opt_N);
(print("NCSA host required!\n") && print_usage() && exit $ERRORS{'UNKNOWN'}) unless ($opt_N);

$opt_U = shift unless ($opt_U);

# Debug
$opt_d = shift unless ($opt_d);
$debug = $opt_d;

my $nsca_str;
unless ($opt_U) {
    $nsca_str = "$opt_H|0|Host Alive\n";
} else {
    $nsca_str = "$opt_H|2|Host unreachable (forced)\n";
}
&send_nsca($nsca_str, $opt_N);

if ($nagios_hostname_ha) {
    undef $nsca_str;
    my $drbd = &check_drbd();
    unless ($opt_U) {
	if ($drbd == 1) {
	    # Host UP
	    $nsca_str = "$nagios_hostname_ha|0|HA Host Alive\n";
	} elsif ($drbd == -1) {
	    # Host DOWN
	    $nsca_str = "$nagios_hostname_ha|1|HA Host Down\n";
	}
    } else { 
	$nsca_str = "$nagios_hostname_ha|2|HA Host unreachable (forced)\n";
    }
    &send_nsca($nsca_str, $opt_N) if defined $nsca_str;
} 


sub print_usage() {
    print "\nUsage:\n";
    print "$PROGNAME\n";
    print "   -N (--nsca)         NCSA host to send passive check (required)\n";
    print "   -H (--hostname)     Nagios hostname (required)\n";
    print "   -U (--unreachable)  Force status UNREACHABLE for host\n";
    print "   -d (--debug)        Enable NSCA debug (default disabled)\n";
    print "   -V (--version)      Plugin version\n";
    print "   -h (--help)         usage help\n";
}
